[cvs] expresso commit by lhamel: javadoc, param names

JCorporate Ltd jcorp at jcorporate.com
Fri Feb 18 19:43:38 UTC 2005


Log Message:
-----------
javadoc, param names

Modified Files:
--------------
    expresso/expresso-web/WEB-INF/src/com/jcorporate/expresso/core/dbobj:
        DBObjectDef.java

Revision Data
-------------
Index: DBObjectDef.java
===================================================================
RCS file: /home/javacorp/.cvs/expresso/expresso/expresso-web/WEB-INF/src/com/jcorporate/expresso/core/dbobj/DBObjectDef.java,v
retrieving revision 1.49
retrieving revision 1.50
diff -Lexpresso-web/WEB-INF/src/com/jcorporate/expresso/core/dbobj/DBObjectDef.java -Lexpresso-web/WEB-INF/src/com/jcorporate/expresso/core/dbobj/DBObjectDef.java -u -r1.49 -r1.50
--- expresso-web/WEB-INF/src/com/jcorporate/expresso/core/dbobj/DBObjectDef.java
+++ expresso-web/WEB-INF/src/com/jcorporate/expresso/core/dbobj/DBObjectDef.java
@@ -313,18 +313,19 @@
 
     /**
      * Specify a new "detail" db object, and the fields in this object
-     * they specify the fields in the related object
+     * that are the foreign key to the fields in the related object.  This is typically
+     * done to enable cascading deletion of detail records.
      *
      * @param objName          The class name of the related object. There is assumed to be
      *                         a one to one or one to many relationship from this object to the specified object
      * @param keyFieldsLocal   A pipe-delimited list of field names in this object
      * @param keyFieldsForeign A pipe-delimieted list of field names in the other object
      */
-    synchronized public void addDetail(String objName, String keyFieldsLocal,
-                                       String keyFieldsForeign)
+    synchronized public void addDetail(String detailObjectName, String keyFieldsLocalMaster,
+                                       String keyFieldsForeignDetail)
             throws DBException {
-        detailObjsLocal.put(objName, keyFieldsLocal);
-        detailObjsForeign.put(objName, keyFieldsForeign);
+        detailObjsLocal.put(detailObjectName, keyFieldsLocalMaster);
+        detailObjsForeign.put(detailObjectName, keyFieldsForeignDetail);
     }
 
     public Enumeration getDetails() {
@@ -313,18 +313,19 @@
      *
-     * @param objName          The class name of the related object. There is assumed to be
+     * @param detailObjectName          The class name of the related object. There is assumed to be
      *                         a one to one or one to many relationship from this object to the specified object
@@ -313,18 +313,19 @@
      *                         a one to one or one to many relationship from this object to the specified object
-     * @param keyFieldsLocal   A pipe-delimited list of field names in this object
-     * @param keyFieldsForeign A pipe-delimieted list of field names in the other object
+     * @param keyFieldsLocalMaster   A pipe-delimited list of field names in this object
+     * @param keyFieldsForeignDetail A pipe-delimieted list of field names in the other object
      */


More information about the cvs mailing list